﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Data;

namespace UserStageExample.ValueConverters
{
    /// <summary>
    /// An enumerations converter
    /// </summary>
    /// <remarks>
    /// Allows you to convert enumerations to Visiblity values and to bool
    /// Also converts bool to enumerations values
    /// </remarks>
    internal class EnumConverter : IValueConverter
    {
        /// <summary>
        /// Converts an Enumerations value to the bool type
        /// </summary>
        /// <param name="value">Value</param>
        /// <param name="targetType">Target type: Visiblity or bool</param>
        /// <param name="parameter">Value being compared (as a line or as is)</param>
        /// <param name="culture">Is not significant</param>
        /// <returns></returns>
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            var target = parameter.GetType() == value.GetType() ? parameter : Enum.Parse(value.GetType(), parameter.ToString());
            var equals = value.Equals(target);
            if (targetType == typeof(bool) || targetType == typeof(bool?))
                return equals;
            return equals ? Visibility.Visible : Visibility.Hidden;
        }

        /// <summary>
        /// Comverts the bool value to an enumerations type
        /// </summary>
        /// <remarks>
        /// Can be used with radio buttons
        /// </remarks>
        /// <param name="value">Bool value</param>
        /// <param name="targetType">Enumeration type</param>
        /// <param name="parameter">Enumeration value that must be set if value == true</param>
        /// <param name="culture">Not used</param>
        /// <returns></returns>
        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            var target = parameter.GetType() == value.GetType() ? parameter : Enum.Parse(targetType, parameter.ToString());
            if ((bool)value) return target;
            return null;
        }
    }
}
